emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 06a12b0cccb: ; Fix typos


From: Stefan Kangas
Subject: master 06a12b0cccb: ; Fix typos
Date: Sun, 10 Dec 2023 07:22:18 -0500 (EST)

branch: master
commit 06a12b0cccbda419752f3388346be7d302ebcbeb
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Fix typos
---
 ChangeLog.android                            | 26 +++++++++++++-------------
 admin/notes/java                             |  6 +++---
 configure.ac                                 |  2 +-
 cross/ndk-build/README                       |  4 ++--
 doc/emacs/android.texi                       |  6 +++---
 doc/emacs/haiku.texi                         |  2 +-
 doc/lispref/commands.texi                    |  4 ++--
 doc/lispref/frames.texi                      |  2 +-
 doc/lispref/minibuf.texi                     |  2 +-
 doc/lispref/searching.texi                   |  2 +-
 doc/lispref/text.texi                        |  2 +-
 doc/misc/ert.texi                            |  2 +-
 doc/misc/modus-themes.org                    | 14 +++++++-------
 etc/DEBUG                                    |  2 +-
 etc/NEWS                                     |  2 +-
 etc/PROBLEMS                                 |  2 +-
 etc/themes/modus-operandi-tinted-theme.el    |  4 ++--
 etc/themes/modus-themes.el                   |  2 +-
 exec/exec1.c                                 |  2 +-
 exec/trace.c                                 |  2 +-
 java/INSTALL                                 |  4 ++--
 java/org/gnu/emacs/EmacsContextMenu.java     |  2 +-
 java/org/gnu/emacs/EmacsInputConnection.java |  2 +-
 java/org/gnu/emacs/EmacsOpenActivity.java    |  2 +-
 java/org/gnu/emacs/EmacsSafThread.java       |  6 +++---
 java/org/gnu/emacs/EmacsService.java         |  8 ++++----
 java/org/gnu/emacs/EmacsView.java            |  2 +-
 java/org/gnu/emacs/EmacsWindow.java          |  2 +-
 lisp/button.el                               |  2 +-
 lisp/emacs-lisp/byte-opt.el                  |  6 +++---
 lisp/emacs-lisp/bytecomp.el                  | 10 +++++-----
 lisp/emacs-lisp/cl-macs.el                   |  2 +-
 lisp/emacs-lisp/eldoc.el                     |  4 ++--
 lisp/emacs-lisp/ert-font-lock.el             |  2 +-
 lisp/emacs-lisp/gv.el                        |  2 +-
 lisp/emacs-lisp/package-vc.el                |  2 +-
 lisp/erc/erc-status-sidebar.el               |  2 +-
 lisp/eshell/em-hist.el                       |  2 +-
 lisp/jsonrpc.el                              |  2 +-
 lisp/minibuffer.el                           |  4 ++--
 lisp/net/shr.el                              |  2 +-
 lisp/net/tramp-crypt.el                      |  2 +-
 lisp/net/tramp-message.el                    |  2 +-
 lisp/progmodes/cc-engine.el                  |  6 +++---
 lisp/progmodes/cperl-mode.el                 |  4 ++--
 lisp/progmodes/gud.el                        |  4 ++--
 lisp/simple.el                               |  2 +-
 lisp/term/android-win.el                     |  2 +-
 lisp/touch-screen.el                         |  4 ++--
 lisp/transient.el                            |  2 +-
 lisp/treesit.el                              |  2 +-
 lisp/use-package/use-package-core.el         |  4 ++--
 src/android.c                                |  4 ++--
 src/androidselect.c                          |  2 +-
 src/androidterm.c                            |  4 ++--
 src/androidterm.h                            |  2 +-
 src/androidvfs.c                             |  8 ++++----
 src/fileio.c                                 |  2 +-
 src/image.c                                  |  2 +-
 src/process.c                                |  2 +-
 src/regex-emacs.c                            |  2 +-
 src/sfnt.c                                   | 14 +++++++-------
 src/sfnt.h                                   |  2 +-
 src/sfntfont.c                               |  6 +++---
 src/textconv.c                               |  6 +++---
 src/treesit.c                                |  2 +-
 src/window.h                                 |  2 +-
 src/xselect.c                                |  2 +-
 src/xterm.c                                  | 10 +++++-----
 test/lisp/emacs-lisp/bytecomp-tests.el       |  8 ++++----
 test/lisp/erc/erc-scenarios-base-attach.el   |  4 ++--
 test/lisp/erc/erc-tests.el                   |  4 ++--
 test/lisp/eshell/em-hist-tests.el            |  2 +-
 test/lisp/eshell/esh-io-tests.el             |  2 +-
 test/lisp/proced-tests.el                    |  2 +-
 test/lisp/thingatpt-tests.el                 |  6 +++---
 test/src/regex-emacs-tests.el                |  2 +-
 77 files changed, 148 insertions(+), 148 deletions(-)

diff --git a/ChangeLog.android b/ChangeLog.android
index 8cc66c4d7ea..96419ebe351 100644
--- a/ChangeLog.android
+++ b/ChangeLog.android
@@ -700,7 +700,7 @@
        (build-counter.c): New target.  Generate this file using
        makecounter.sh upon changes to lisp.mk or shortlisp.
        (lisp.mk): Make and load relative to abs_top_builddir.
-       (emacs$(EXEEXT)): Adjust acordingly.
+       (emacs$(EXEEXT)): Adjust accordingly.
        (mostlyclean): Remove build-counter.c.
 
 2023-07-18  Po Lu  <luangruo@yahoo.com>
@@ -735,7 +735,7 @@
        prototypes.
 
        * java/org/gnu/emacs/EmacsWindow.java (motionEvent): Set
-       cancelation flag in events sent where appropriate.
+       cancellation flag in events sent where appropriate.
 
        * lisp/touch-screen.el (touch-screen-handle-point-update):
        Improve treatment of horizontal scrolling near window edges.
@@ -749,7 +749,7 @@
        (struct android_touch_event): New field `flags'.
 
        * src/androidterm.c (handle_one_android_event): Report
-       cancelation in TOUCHSCREEN_END_EVENTs.
+       cancellation in TOUCHSCREEN_END_EVENTs.
 
        * src/keyboard.c (make_lispy_event): Fix botched merge.
 
@@ -1005,7 +1005,7 @@
 
        * java/org/gnu/emacs/EmacsWindow.java (Coordinate): New fields
        `button' and `id'.
-       (<init>): Add new arguments to the construtor.
+       (<init>): Add new arguments to the constructor.
        (whatButtonWasIt): Return 0 if the button state has not changed.
        (buttonForEvent): New function.
        (figureChange): Return the Coordinate object associated to EVENT.
@@ -2384,7 +2384,7 @@
        (sfnt_read_avar_table): Fix sequencing problem.
 
        * src/sfntfont.c (sfntfont_setup_interpreter): Don't create
-       interpreter for blatently broken fonts.
+       interpreter for blatantly broken fonts.
        (sfntfont_open): Avoid specifying redundant blends.
 
        * src/sfnt.c (sfnt_validate_gs): Fix validation of projection
@@ -3466,7 +3466,7 @@
        (src/verbose.mk): Depend on verbose.mk.android in srcdir.
        (lib/Makefile): Edit srcdir and VPATH to LIB_SRCDIR.
        (src/Makefile): Edit -I$$(top_srcdir) to -I../$(srcdir)/lib,
-       instead of ommitting it.
+       instead of omitting it.
        (clean): Allow ndk-build clean to fail.
 
        * java/Makefile.in (builddir): New variable.
@@ -3714,7 +3714,7 @@
        module detection.
 
        * src/android.c (android_run_select_thread): Fix typos.
-       (android_run_select_thread): Lock select_mutex before signalling
+       (android_run_select_thread): Lock select_mutex before signaling
        condition variable.
        (android_select): Unlock event queue mutex prior to waiting for
        it.
@@ -4663,7 +4663,7 @@
        (ndk_CONFIG_FILES): Export NDK_BUILD_CFLAGS.
 
        * java/AndroidManifest.xml.in: Prevent the Emacs activity from
-       being overlayed by the emacsclient wrapper.
+       being overlaid by the emacsclient wrapper.
        * java/org/gnu/emacs/EmacsOpenActivity.java (run): Likewise.
        (onCreate): Set an appropriate theme on ICS and up.
 
@@ -5151,7 +5151,7 @@
        * m4/ndk-build.m4 (ndk_package_mape): Add package mapping for
        sqlite3.
 
-       * src/Makefile.in (SQLITE3_CFLAGS): New substition.
+       * src/Makefile.in (SQLITE3_CFLAGS): New substitution.
        (EMACS_CFLAGS): Add that variable.
 
        * src/android.c (android_api_level): New variable.
@@ -5532,7 +5532,7 @@
        (touch-screen-precision-scroll): New user option.
        (touch-screen-handle-scroll): Use traditional scrolling by
        default.
-       (touch-screen-handle-touch): Adust format of
+       (touch-screen-handle-touch): Adjust format of
        touch-screen-current-tool.
        (touch-screen-track-tap): Don't print waiting for events.
        (touch-screen-track-drag): Likewise.  Also, don't call UPDATE
@@ -5555,7 +5555,7 @@
        * lisp/ls-lisp.el (ls-lisp-use-insert-directory-program): Default
        to off on Android.
 
-       * src/android.c (android_is_directory): New fucntion.
+       * src/android.c (android_is_directory): New function.
        (android_fstatat): Handle directories created by
        `android_opendir'.
        (android_open): Return meaningful file mode.
@@ -5645,7 +5645,7 @@
        * java/org/gnu/emacs/EmacsNative.java (EmacsNative): Make all
        event sending functions return long.
 
-       * java/org/gnu/emacs/EmacsPreferencesActivity.java: New fle.
+       * java/org/gnu/emacs/EmacsPreferencesActivity.java: New file.
 
        * java/org/gnu/emacs/EmacsService.java (EmacsService)
        (onStartCommand, onCreate, startEmacsService): Start as a
@@ -6310,7 +6310,7 @@
        and `detectMouse'.
        (struct android_event_queue, android_init_events)
        (android_next_event, android_write_event): Remove write limit.
-       (android_file_access_p): Handle directories correcty.
+       (android_file_access_p): Handle directories correctly.
        (android_close): Fix coding style.
        (android_fclose): New function.
        (android_init_emacs_service): Initialize new methods.
diff --git a/admin/notes/java b/admin/notes/java
index 125ac0aad67..6a66d1aa765 100644
--- a/admin/notes/java
+++ b/admin/notes/java
@@ -15,7 +15,7 @@ Java is required because the entire Android runtime is based 
around
 Java, and there is no way to write an Android program which runs
 without Java.
 
-This text exists to prime other Emacs developers, already familar with
+This text exists to prime other Emacs developers, already familiar with
 C, on the basic architecture of the Android port, and to teach them
 how to read and write the Java code found in this directory.
 
@@ -570,7 +570,7 @@ Let us go back and review the definition of 
``startEmacsService'':
          context.startService (new Intent (context,
                                            EmacsService.class));
        else
-         /* Display the permanant notification and start Emacs as a
+         /* Display the permanent notification and start Emacs as a
             foreground service.  */
          context.startForegroundService (new Intent (context,
                                                      EmacsService.class));
@@ -796,7 +796,7 @@ Next, `max_handle' is saved, and a new handle is allocated 
for
   if (!window)
     error ("Out of window handles!");
 
-An error is signalled if Emacs runs out of available handles.
+An error is signaled if Emacs runs out of available handles.
 
   if (!class)
     {
diff --git a/configure.ac b/configure.ac
index 759dcd14d50..a279f78a0ea 100644
--- a/configure.ac
+++ b/configure.ac
@@ -306,7 +306,7 @@ AC_DEFUN([OPTION_DEFAULT_OFF], [dnl
 
 dnl OPTION_DEFAULT_IFAVAILABLE(NAME, HELP-STRING)
 dnl Create a new --with option that defaults to 'ifavailable',
-dnl unless it is overriden by $with_features being equal to 'no'.
+dnl unless it is overridden by $with_features being equal to 'no'.
 dnl NAME is the base name of the option.  The shell variable with_NAME
 dnl   will be set to either the user's value (if the option is
 dnl   specified; 'yes' for a plain --with-NAME) or to 'ifavailable' (if the
diff --git a/cross/ndk-build/README b/cross/ndk-build/README
index aca2e7230bf..d6cf2908014 100644
--- a/cross/ndk-build/README
+++ b/cross/ndk-build/README
@@ -86,7 +86,7 @@ $(ANDROID_MAKEFILE), the ``Android.mk'' file, for the first 
time.  The
 purpose of this evaluation is to establish a list of packages (or
 modules) provided by the ``Android.mk'' file, and the corresponding
 Makefile targets and compiler and linker flags required to build and
-link to those tagets.
+link to those targets.
 
 Before doing so, build-aux/ndk-build-helper.mk will define several
 variables and functions required by all ``Android.mk'' files.  The
@@ -164,7 +164,7 @@ module_cxx_deps=""
 module_imports=""
 
 which is then evaluated by `configure'.         Once the variable
-`module_name' is set, configure apends the remaining
+`module_name' is set, configure appends the remaining
 $(module_includes), $(module_cflags) and $(module_ldflags) to the
 module's CFLAGS and LIBS variables, and appends the list of Makefile
 targets specified to the variable NDK_BUILD_MODULES.
diff --git a/doc/emacs/android.texi b/doc/emacs/android.texi
index 52912d045eb..fe73bc09d67 100644
--- a/doc/emacs/android.texi
+++ b/doc/emacs/android.texi
@@ -234,7 +234,7 @@ Document Providers}.)
 the (normally read-only) root directory named @file{content} or
 @file{assets}, you may want to access real files by these names if the
 Android installation in use has been customized.  These files will
-conflict with the aformentioned special directories, but can
+conflict with the aforementioned special directories, but can
 nevertheless be accessed by writing their names relative to the
 ``parent'' directory of the root directory, as so illustrated:
 @file{/../content}, @file{/../assets}.
@@ -258,7 +258,7 @@ at startup to symlink the application library directory to 
its
 traditional location within the parent of the app data directory.
 
   If Emacs is reinstalled and the location of the app library
-directory consequentially changes, that symlink will also be updated
+directory consequently changes, that symlink will also be updated
 to point to its new location the next time Emacs is started by the
 system.
 
@@ -340,7 +340,7 @@ to its app data directory (@pxref{Android File
 System}.)@footnote{Except in cases where a ``shared user ID'' is
 specified and other applications signed using the same ``package
 signing key'' are installed, in which case Emacs runs as the same user
-and has access to the same files as each of the aformentioned
+and has access to the same files as each of the aforementioned
 applications.}
 
   Each application is also prohibited from accessing many system
diff --git a/doc/emacs/haiku.texi b/doc/emacs/haiku.texi
index 0bb216c14ae..e129fd6f33f 100644
--- a/doc/emacs/haiku.texi
+++ b/doc/emacs/haiku.texi
@@ -10,7 +10,7 @@ re-implementation of the operating system BeOS.
 
   This appendix describes the peculiarities of using Emacs built with
 the Application Kit, the windowing system indigenous to Haiku.  The
-idiosyncracies illustrated here do not apply to Emacs on Haiku built
+idiosyncrasies illustrated here do not apply to Emacs on Haiku built
 without windowing support, or configured with X11.
 
 @menu
diff --git a/doc/lispref/commands.texi b/doc/lispref/commands.texi
index f6462a9e50b..b4226a9ec6f 100644
--- a/doc/lispref/commands.texi
+++ b/doc/lispref/commands.texi
@@ -2151,7 +2151,7 @@ is dismissed (@pxref{Mouse Menus}), Emacs also avoids 
simple
 translation if @code{down-mouse-1} is bound to a keymap, making it a
 prefix key.  In lieu of simple translation, it translates the closing
 @code{touchscreen-end} to a @code{down-mouse-1} event with the
-starting position of the touch sequence, consequentially displaying
+starting position of the touch sequence, consequently displaying
 the mouse menu.
 
 @cindex @code{mouse-1-menu-command}, a symbol property
@@ -2205,7 +2205,7 @@ position of the touchpoint.
 @item (touchscreen-restart-drag @var{posn})
 This event is sent upon the start of a touch sequence resulting in the
 continuation of a ``drag-to-select'' gesture (subject to the
-aformentioned user option) with @var{posn} set to the position list of
+aforementioned user option) with @var{posn} set to the position list of
 the initial @code{touchscreen-begin} event within that touch sequence.
 
 @cindex @code{touchscreen-pinch} event
diff --git a/doc/lispref/frames.texi b/doc/lispref/frames.texi
index ec6f7fd9462..f09ee0afbf4 100644
--- a/doc/lispref/frames.texi
+++ b/doc/lispref/frames.texi
@@ -4160,7 +4160,7 @@ code, for it's only meant to abet synchronization between 
the X
 server, owner and requestor.
 @end itemize
 
-  The selection owner responds by tranferring to the requestor a
+  The selection owner responds by transferring to the requestor a
 series of bytes, 16 bit words, or 32 bit words, along with another
 atom identifying the type of those words.  After requesting a
 selection, Emacs then applies its own interpretation of the data
diff --git a/doc/lispref/minibuf.texi b/doc/lispref/minibuf.texi
index ba7f1ca692e..03c221c6cf6 100644
--- a/doc/lispref/minibuf.texi
+++ b/doc/lispref/minibuf.texi
@@ -1564,7 +1564,7 @@ Interactively, or when @var{display} is non-@code{nil}, 
the return
 value is also displayed in the echo area.
 
 The optional arguments @var{foreground} and @var{face} control the
-appearence of the completion candidates in the @file{*Completions*}
+appearance of the completion candidates in the @file{*Completions*}
 buffer.  The candidates are displayed in the specified @var{face} but
 with different colors: if @var{foreground} is non-@code{nil}, the
 foreground color is changed to be the color of the candidate,
diff --git a/doc/lispref/searching.texi b/doc/lispref/searching.texi
index cb269fcacc5..1a898828eb1 100644
--- a/doc/lispref/searching.texi
+++ b/doc/lispref/searching.texi
@@ -2990,7 +2990,7 @@ values of the variables @code{sentence-end-double-space}
 @section Emacs versus POSIX Regular Expressions
 @cindex POSIX regular expressions
 
-Regular expression syntax varies signficantly among computer programs.
+Regular expression syntax varies significantly among computer programs.
 When writing Elisp code that generates regular expressions for use by other
 programs, it is helpful to know how syntax variants differ.
 To give a feel for the variation, this section discusses how
diff --git a/doc/lispref/text.texi b/doc/lispref/text.texi
index 5d05ef18d4f..b17eb087f42 100644
--- a/doc/lispref/text.texi
+++ b/doc/lispref/text.texi
@@ -6205,7 +6205,7 @@ cons it was set to at the time 
@code{prepare-change-group} was called.
 
   If @code{buffer-undo-list} no longer contains that cons, Emacs will
 lose track of any change groups, resulting in an error when the change
-group is cancelled.  To avoid this, do not call any functions which
+group is canceled.  To avoid this, do not call any functions which
 may edit the undo list in such a manner, when a change group is
 active: notably, ``amalgamating'' commands such as @code{delete-char},
 which call @code{undo-auto-amalgamate}.
diff --git a/doc/misc/ert.texi b/doc/misc/ert.texi
index 892ff4dd5e4..a0adb5fea2c 100644
--- a/doc/misc/ert.texi
+++ b/doc/misc/ert.texi
@@ -954,7 +954,7 @@ comments directly and can be read either from inline 
strings or files.
 
 Test assertion parser extracts tests from comment-only lines.  Every
 comment assertion line starts either with a caret (@samp{^}) or an
-arrow (@samp{<-}).  A caret/arrow should be followed immedately by the
+arrow (@samp{<-}).  A caret/arrow should be followed immediately by the
 name of a face to be checked.
 
 The test then checks if the first non-assertion column above the caret
diff --git a/doc/misc/modus-themes.org b/doc/misc/modus-themes.org
index 7eedc97ab04..bdcb0793098 100644
--- a/doc/misc/modus-themes.org
+++ b/doc/misc/modus-themes.org
@@ -90,7 +90,7 @@ The Modus themes consist of eight themes, divided into four 
subgroups.
   are variants of the two main themes.  They slightly tone down the
   intensity of the background and provide a bit more color variety.
   ~modus-operandi-tinted~ has a set of base tones that are shades of
-  light ochre (earthly colors), while ~modus-vivendi-tinted~ gives a
+  light ocher (earthly colors), while ~modus-vivendi-tinted~ gives a
   night sky impression.
 
 - Deuteranopia themes :: ~modus-operandi-deuteranopia~ and its
@@ -2518,7 +2518,7 @@ manual, here is what Protesilaos uses:
         ;; Add a nuanced background as well.
         (bg-prompt bg-magenta-nuanced)
         (fg-prompt magenta-cooler)
-        ;; Tweak some more constructs for stylistic constistency.
+        ;; Tweak some more constructs for stylistic consistency.
         (name blue-warmer)
         (identifier magenta-faint)
         (keybind magenta-cooler)
@@ -2717,7 +2717,7 @@ For a more elaborate design, it is better to inspect the 
source code of
 [[#h:51ba3547-b8c8-40d6-ba5a-4586477fd4ae][Use theme colors in code with 
modus-themes-with-colors]].
 
 #+findex: modus-themes-get-color-value
-The fuction ~modus-themes-get-color-value~ can be called from Lisp to
+The function ~modus-themes-get-color-value~ can be called from Lisp to
 return the value of a color from the active Modus theme palette.  It
 takea a =COLOR= argument and an optional =OVERRIDES=.
 
@@ -2886,7 +2886,7 @@ above:
 The reason we no longer provide this option is because it depends on a
 non-~nil~ value for ~x-underline-at-descent-line~.  That variable
 affects ALL underlines, including those of links.  The effect is
-intrusive and looks awkard in prose.
+intrusive and looks awkward in prose.
 
 As such, the Modus themes no longer provide that option but instead
 offer this piece of documentation to make the user fully aware of the
@@ -3229,7 +3229,7 @@ specification of that variable looks like this:
 
 With the exception of ~org-verbatim~ and ~org-code~ faces, everything else
 uses the corresponding type of emphasis: a bold typographic weight, or
-italicised, underlined, and struck through text.
+italicized, underlined, and struck through text.
 
 The best way for users to add some extra attributes, such as a
 foreground color, is to define their own faces and assign them to the
@@ -5132,7 +5132,7 @@ it is already understood that one must follow the 
indicator or headline
 to view its contents and (ii) underlining everything would make the
 interface virtually unusable.
 
-Again, one must exercise judgement in order to avoid discrimination,
+Again, one must exercise judgment in order to avoid discrimination,
 where "discrimination" refers to:
 
 + The treatment of substantially different magnitudes as if they were of
@@ -5206,7 +5206,7 @@ the themes, which is partially fleshed out in this manual.
 
 With regard to the artistic aspect (where "art" qua skill may amount to
 an imprecise science), there is no hard-and-fast rule in effect as it
-requires one to exercize discretion and make decisions based on
+requires one to exercise discretion and make decisions based on
 context-dependent information or constraints.  As is true with most
 things in life, when in doubt, do not cling on to the letter of the law
 but try to understand its spirit.
diff --git a/etc/DEBUG b/etc/DEBUG
index 5aeb38c6460..86bff45e7d9 100644
--- a/etc/DEBUG
+++ b/etc/DEBUG
@@ -1142,7 +1142,7 @@ one to upload, like so:
   ../java/debug.sh --gdbserver /path/to/gdbserver
 
 This Gdbserver should be statically linked or compiled using the
-Android NDK, and must target the same architecture as the debugee
+Android NDK, and must target the same architecture as the debugged
 Emacs binary.  Older versions of the Android NDK (such as r24)
 distribute suitable Gdbserver binaries, usually located within
 
diff --git a/etc/NEWS b/etc/NEWS
index fbfe1084b8f..33afb34b029 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -1224,7 +1224,7 @@ This user option has been obsoleted in Emacs 27, use
 ---
 ** User options 'eshell-NAME-unload-hook' are now obsolete.
 These hooks were named incorrectly, and so they never actually ran
-when unloading the correspending feature.  Instead, you should use
+when unloading the corresponding feature.  Instead, you should use
 hooks named after the feature name, like 'esh-mode-unload-hook'.
 
 +++
diff --git a/etc/PROBLEMS b/etc/PROBLEMS
index 7159fe32c1c..e42e3c4d87a 100644
--- a/etc/PROBLEMS
+++ b/etc/PROBLEMS
@@ -3539,7 +3539,7 @@ The Microsoft scaler and FreeType promptly disregard such 
points.
 
 Nothing in the TrueType specifications implies that points "hidden" in
 this fashion should be afforded any special treatment, and thus Emacs
-eschews doing so.  Consequentially, black streaks are displayed as
+eschews doing so.  Consequently, black streaks are displayed as
 Emacs interpolates glyph edges between points within the glyph and
 points the test font attempts to hide.
 
diff --git a/etc/themes/modus-operandi-tinted-theme.el 
b/etc/themes/modus-operandi-tinted-theme.el
index e66a030650c..1ef7af8f165 100644
--- a/etc/themes/modus-operandi-tinted-theme.el
+++ b/etc/themes/modus-operandi-tinted-theme.el
@@ -1,4 +1,4 @@
-;;; modus-operandi-tinted-theme.el --- Elegant, highly legible theme with a 
light ochre background -*- lexical-binding:t -*-
+;;; modus-operandi-tinted-theme.el --- Elegant, highly legible theme with a 
light ocher background -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2019-2023  Free Software Foundation, Inc.
 
@@ -44,7 +44,7 @@
 
 ;;;###theme-autoload
   (deftheme modus-operandi-tinted
-    "Elegant, highly legible theme with a light ochre background.
+    "Elegant, highly legible theme with a light ocher background.
 Conforms with the highest legibility standard for color contrast
 between background and foreground in any given piece of text,
 which corresponds to a minimum contrast in relative luminance of
diff --git a/etc/themes/modus-themes.el b/etc/themes/modus-themes.el
index 34130a05515..0f7bc025b72 100644
--- a/etc/themes/modus-themes.el
+++ b/etc/themes/modus-themes.el
@@ -1535,7 +1535,7 @@ color that is combined with FG-FOR-BG."
           :foreground fg
           :weight
           ;; If we have `bold' specifically, we inherit the face of
-          ;; the same name.  This allows the user to customise that
+          ;; the same name.  This allows the user to customize that
           ;; face, such as to change its font family.
           (if (and weight (not (eq weight 'bold)))
               weight
diff --git a/exec/exec1.c b/exec/exec1.c
index d77ca8adf54..6ec4b3ecaae 100644
--- a/exec/exec1.c
+++ b/exec/exec1.c
@@ -53,7 +53,7 @@ main (int argc, char **argv)
 
       tracing_execve (argv[2], argv + 2, environ);
 
-      /* An error occured.  Exit with failure.  */
+      /* An error occurred.  Exit with failure.  */
       exit (127);
     }
   else
diff --git a/exec/trace.c b/exec/trace.c
index f9deef8eb2d..ccf498f39fe 100644
--- a/exec/trace.c
+++ b/exec/trace.c
@@ -1028,7 +1028,7 @@ process_system_call (struct exec_tracee *tracee)
          break;
 
        case 1:
-         /* An error has occured; errno is set to the error.  */
+         /* An error has occurred; errno is set to the error.  */
          goto report_syscall_error;
        }
 
diff --git a/java/INSTALL b/java/INSTALL
index fb221c5e2b4..60171ada57c 100644
--- a/java/INSTALL
+++ b/java/INSTALL
@@ -167,7 +167,7 @@ than a compressed package for a newer version of Android.
 BUILDING C++ DEPENDENCIES
 
 With a new version of the NDK, dependencies containing C++ code should
-build without any futher configuration.  However, older versions
+build without any further configuration.  However, older versions
 require that you use the ``make_standalone_toolchain.py'' script in
 the NDK distribution to create a ``standalone toolchain'', and use
 that instead, in order for C++ headers to be found.
@@ -309,7 +309,7 @@ work, along with what has to be patched to make them work:
 Many of these dependencies have been migrated over to the
 ``Android.bp'' build system now used to build Android itself.
 However, the old ``Android.mk'' Makefiles are still present in older
-branches, and can be easily adapte to newer versions.
+branches, and can be easily adapted to newer versions.
 
 In addition, some Emacs dependencies provide `ndk-build' support
 themselves:
diff --git a/java/org/gnu/emacs/EmacsContextMenu.java 
b/java/org/gnu/emacs/EmacsContextMenu.java
index c415ba59c79..2652f35b545 100644
--- a/java/org/gnu/emacs/EmacsContextMenu.java
+++ b/java/org/gnu/emacs/EmacsContextMenu.java
@@ -36,7 +36,7 @@ import android.view.SubMenu;
 import android.util.Log;
 
 /* Context menu implementation.  This object is built from JNI and
-   describes a menu hiearchy.  Then, `inflate' can turn it into an
+   describes a menu hierarchy.  Then, `inflate' can turn it into an
    Android menu, which can be turned into a popup (or other kind of)
    menu.  */
 
diff --git a/java/org/gnu/emacs/EmacsInputConnection.java 
b/java/org/gnu/emacs/EmacsInputConnection.java
index 7f6331205cb..4b493dcc456 100644
--- a/java/org/gnu/emacs/EmacsInputConnection.java
+++ b/java/org/gnu/emacs/EmacsInputConnection.java
@@ -60,7 +60,7 @@ public final class EmacsInputConnection implements 
InputConnection
 
      This helps with on screen keyboard programs found in some vendor
      versions of Android, which rely on immediate updates to the point
-     position after text is commited in order to place the cursor
+     position after text is committed in order to place the cursor
      within that text.  */
 
   private static boolean syncAfterCommit;
diff --git a/java/org/gnu/emacs/EmacsOpenActivity.java 
b/java/org/gnu/emacs/EmacsOpenActivity.java
index 32a79d1a797..b4fd68146be 100644
--- a/java/org/gnu/emacs/EmacsOpenActivity.java
+++ b/java/org/gnu/emacs/EmacsOpenActivity.java
@@ -636,7 +636,7 @@ public final class EmacsOpenActivity extends Activity
                  {
                    /* This means Emacs lacks the rights to open this
                       file.  Display the error message and exit.  */
-                   displayFailureDialog ("Error openining file",
+                   displayFailureDialog ("Error opening file",
                                          exception.toString ());
                    return;
                  }
diff --git a/java/org/gnu/emacs/EmacsSafThread.java 
b/java/org/gnu/emacs/EmacsSafThread.java
index 7917e2d4880..8bb84126b07 100644
--- a/java/org/gnu/emacs/EmacsSafThread.java
+++ b/java/org/gnu/emacs/EmacsSafThread.java
@@ -767,7 +767,7 @@ public final class EmacsSafThread extends HandlerThread
 
   private abstract class SafIntFunction
   {
-    /* The ``throws Throwable'' here is a Java idiosyncracy that tells
+    /* The ``throws Throwable'' here is a Java idiosyncrasy that tells
        the compiler to allow arbitrary error objects to be signaled
        from within this function.
 
@@ -782,7 +782,7 @@ public final class EmacsSafThread extends HandlerThread
 
   private abstract class SafObjectFunction
   {
-    /* The ``throws Throwable'' here is a Java idiosyncracy that tells
+    /* The ``throws Throwable'' here is a Java idiosyncrasy that tells
        the compiler to allow arbitrary error objects to be signaled
        from within this function.
 
@@ -1216,7 +1216,7 @@ public final class EmacsSafThread extends HandlerThread
       });
   }
 
-  /* The bulk of `statDocument'.  SIGNAL should be a cancelation
+  /* The bulk of `statDocument'.  SIGNAL should be a cancellation
      signal.  */
 
   private long[]
diff --git a/java/org/gnu/emacs/EmacsService.java 
b/java/org/gnu/emacs/EmacsService.java
index 33832505333..c71670b3e47 100644
--- a/java/org/gnu/emacs/EmacsService.java
+++ b/java/org/gnu/emacs/EmacsService.java
@@ -612,7 +612,7 @@ public final class EmacsService extends Service
          context.startService (new Intent (context,
                                            EmacsService.class));
        else
-         /* Display the permanant notification and start Emacs as a
+         /* Display the permanent notification and start Emacs as a
             foreground service.  */
          context.startForegroundService (new Intent (context,
                                                      EmacsService.class));
@@ -679,7 +679,7 @@ public final class EmacsService extends Service
            /* Display a list of programs able to send this URL.  */
            intent = Intent.createChooser (intent, "Send");
 
-           /* Apparently flags need to be set after a choser is
+           /* Apparently flags need to be set after a chooser is
               created.  */
            intent.addFlags (Intent.FLAG_ACTIVITY_NEW_TASK);
          }
@@ -927,7 +927,7 @@ public final class EmacsService extends Service
 
     if (Build.VERSION.SDK_INT < Build.VERSION_CODES.N)
       /* Since the system predates drag and drop, return this resolver
-        to avoid any unforseen difficulties.  */
+        to avoid any unforeseen difficulties.  */
       return resolver;
 
     activity = EmacsActivity.lastFocusedActivity;
@@ -947,7 +947,7 @@ public final class EmacsService extends Service
 
     if (Build.VERSION.SDK_INT < Build.VERSION_CODES.N)
       /* Since the system predates drag and drop, return this resolver
-        to avoid any unforseen difficulties.  */
+        to avoid any unforeseen difficulties.  */
       return this;
 
     activity = EmacsActivity.lastFocusedActivity;
diff --git a/java/org/gnu/emacs/EmacsView.java 
b/java/org/gnu/emacs/EmacsView.java
index 2d53231fbf9..5795f476f63 100644
--- a/java/org/gnu/emacs/EmacsView.java
+++ b/java/org/gnu/emacs/EmacsView.java
@@ -388,7 +388,7 @@ public final class EmacsView extends ViewGroup
                && !rootWindowInsets.isVisible (WindowInsets.Type.ime ())
                /* N.B. that the keyboard is dismissed during gesture
                   navigation under Android 30, but the system is
-                  quite tempermental regarding whether the window is
+                  quite temperamental regarding whether the window is
                   focused at that point.  Ideally
                   isCurrentlyTextEditor shouldn't be reset in that
                   case, but detecting that situation appears to be
diff --git a/java/org/gnu/emacs/EmacsWindow.java 
b/java/org/gnu/emacs/EmacsWindow.java
index 7d161fdcf88..2c446913eba 100644
--- a/java/org/gnu/emacs/EmacsWindow.java
+++ b/java/org/gnu/emacs/EmacsWindow.java
@@ -1399,7 +1399,7 @@ public final class EmacsWindow extends EmacsHandleObject
                  }
 
                /* Effect the same adjustment upon the view
-                  hiearchy.  */
+                  hierarchy.  */
 
                EmacsService.SERVICE.runOnUiThread (new Runnable () {
                    @Override
diff --git a/lisp/button.el b/lisp/button.el
index ed11c9583d8..4d66fc57d87 100644
--- a/lisp/button.el
+++ b/lisp/button.el
@@ -494,7 +494,7 @@ pushing a button, use the `button-describe' command."
                (button-activate str t)
               (if (eq (car-safe pos) 'touchscreen-down)
                   ;; If touch-screen-track tap returns nil, then the
-                  ;; tap was cancelled.
+                  ;; tap was canceled.
                   (when (touch-screen-track-tap pos nil nil t)
                     (push-button (posn-point posn) t))
                 (push-button (posn-point posn) t))))))
diff --git a/lisp/emacs-lisp/bytecomp.el b/lisp/emacs-lisp/bytecomp.el
index 64fd4f6b3f3..950ae77803c 100644
--- a/lisp/emacs-lisp/bytecomp.el
+++ b/lisp/emacs-lisp/bytecomp.el
@@ -3566,7 +3566,7 @@ lambda-expression."
             (cond
              ((and sef (or (eq sef 'error-free)
                            byte-compile-delete-errors))
-              ;; This transform is normally done in the Lisp optimiser,
+              ;; This transform is normally done in the Lisp optimizer,
               ;; so maybe we don't need to bother about it here?
               (setq form (cons 'progn (cdr form)))
               (setq handler #'byte-compile-progn))
@@ -3603,7 +3603,7 @@ lambda-expression."
 (let ((important-return-value-fns
        '(
          ;; These functions are side-effect-free except for the
-         ;; behaviour of functions passed as argument.
+         ;; behavior of functions passed as argument.
          mapcar mapcan mapconcat
          assoc plist-get plist-member
 
@@ -4148,7 +4148,7 @@ If it is nil, then the handler is 
\"byte-compile-SYMBOL.\""
     (byte-compile-two-args
      (if (macroexp-const-p (nth 1 form))
          ;; First argument is constant: flip it so that the constant
-         ;; is last, which may allow more lapcode optimisations.
+         ;; is last, which may allow more lapcode optimizations.
          (let* ((op (car form))
                 (flipped-op (cdr (assq op '((< . >) (<= . >=)
                                             (> . <) (>= . <=) (= . =))))))
@@ -4312,7 +4312,7 @@ This function is never called when `lexical-binding' is 
nil."
            (arg2 (nth 2 form)))
        (when (and (memq (car form) '(+ *))
                   (macroexp-const-p arg1))
-         ;; Put constant argument last for better LAP optimisation.
+         ;; Put constant argument last for better LAP optimization.
          (cl-rotatef arg1 arg2))
        (byte-compile-form arg1)
        (byte-compile-form arg2)
@@ -5326,7 +5326,7 @@ FORM is used to provide location, 
`bytecomp--cus-function' and
   "Warn about common mistakes in the `defcustom' type TYPE."
   (let ((invalid-types
          '(
-           ;; Lisp type predicates, often confused with customisation types:
+           ;; Lisp type predicates, often confused with customization types:
            functionp numberp integerp fixnump natnump floatp booleanp
            characterp listp stringp consp vectorp symbolp keywordp
            hash-table-p facep
diff --git a/lisp/emacs-lisp/cl-macs.el b/lisp/emacs-lisp/cl-macs.el
index 2431e658368..7b69404cfac 100644
--- a/lisp/emacs-lisp/cl-macs.el
+++ b/lisp/emacs-lisp/cl-macs.el
@@ -3739,7 +3739,7 @@ macro that returns its `&whole' argument."
 (mapc (lambda (x) (function-put x 'important-return-value t))
        '(
          ;; Functions that are side-effect-free except for the
-         ;; behaviour of functions passed as argument.
+         ;; behavior of functions passed as argument.
          cl-mapcar cl-mapcan cl-maplist cl-map cl-mapcon
          cl-reduce
          cl-assoc cl-assoc-if cl-assoc-if-not
diff --git a/lisp/emacs-lisp/eldoc.el b/lisp/emacs-lisp/eldoc.el
index e28d73c3555..4ee825136c9 100644
--- a/lisp/emacs-lisp/eldoc.el
+++ b/lisp/emacs-lisp/eldoc.el
@@ -607,7 +607,7 @@ known to be truncated."
 
 (defun eldoc-display-in-echo-area (docs interactive)
   "Display DOCS in echo area.
-INTERACTIVE is non-nil if user explictly invoked ElDoc.  Honor
+INTERACTIVE is non-nil if user explicitly invoked ElDoc.  Honor
 `eldoc-echo-area-use-multiline-p' and
 `eldoc-echo-area-prefer-doc-buffer'."
   (cond
@@ -933,7 +933,7 @@ the docstrings eventually produced, using
       (let* ((eldoc--make-callback #'make-callback)
              (res (funcall eldoc-documentation-strategy)))
         ;; Observe the old and the new protocol:
-        (cond (;; Old protocol: got string, e-d-strategy is iself the
+        (cond (;; Old protocol: got string, e-d-strategy is itself the
                ;; origin function, and we output immediately;
                (stringp res)
                (register-doc 0 res nil eldoc-documentation-strategy)
diff --git a/lisp/emacs-lisp/ert-font-lock.el b/lisp/emacs-lisp/ert-font-lock.el
index 6a02cf7acc4..8bde83bf278 100644
--- a/lisp/emacs-lisp/ert-font-lock.el
+++ b/lisp/emacs-lisp/ert-font-lock.el
@@ -28,7 +28,7 @@
 ;;
 ;; ert-font-lock entry points are functions
 ;; `ert-font-lock-test-string' and `ert-font-lock-test-file' and
-;; covenience macros: `ert-font-lock-deftest' and
+;; convenience macros: `ert-font-lock-deftest' and
 ;; `ert-font-lock-deftest-file'.
 ;;
 ;; See unit tests in ert-font-lock-tests.el for usage examples.
diff --git a/lisp/emacs-lisp/gv.el b/lisp/emacs-lisp/gv.el
index 5d31253fe2d..9f40c1f3c93 100644
--- a/lisp/emacs-lisp/gv.el
+++ b/lisp/emacs-lisp/gv.el
@@ -638,7 +638,7 @@ REF must have been previously obtained with `gv-ref'."
 
 ;;; Generalized variables.
 
-;; You'd think noone would write `(setf (error ...) ..)' but it
+;; You'd think no one would write `(setf (error ...) ..)' but it
 ;; appears naturally as the result of macroexpansion of things like
 ;; (setf (pcase-exhaustive ...)).
 ;; We could generalize this to `throw' and `signal', but it seems
diff --git a/lisp/emacs-lisp/package-vc.el b/lisp/emacs-lisp/package-vc.el
index bc36762cb2d..bef498f997c 100644
--- a/lisp/emacs-lisp/package-vc.el
+++ b/lisp/emacs-lisp/package-vc.el
@@ -863,7 +863,7 @@ package uses `file-name-base' on the URL to obtain the 
package
 name, otherwise NAME is the package name as a symbol.
 
 PACKAGE can also be a cons cell (PNAME . SPEC) where PNAME is the
-package name as a symbol, and SPEC is a plist that specifes how
+package name as a symbol, and SPEC is a plist that specifies how
 to fetch and build the package.  For possible values, see the
 subsection \"Specifying Package Sources\" in the Info
 node `(emacs)Fetching Package Sources'.
diff --git a/lisp/erc/erc-status-sidebar.el b/lisp/erc/erc-status-sidebar.el
index d2ecce94bcd..98d5a321385 100644
--- a/lisp/erc/erc-status-sidebar.el
+++ b/lisp/erc/erc-status-sidebar.el
@@ -130,7 +130,7 @@ buffers, using the functions
   `erc-status-sidebar-pad-hierarchy'
 
 for the above-mentioned purposes.  ERC also accepts a list of
-functions to preform these roles a la carte.  Since the members
+functions to perform these roles a la carte.  Since the members
 of the above sets aren't really interoperable, we don't offer
 them here as customization choices, but you can still specify
 them manually.  See doc strings for a description of their
diff --git a/lisp/eshell/em-hist.el b/lisp/eshell/em-hist.el
index 79336204847..9b1bc009079 100644
--- a/lisp/eshell/em-hist.el
+++ b/lisp/eshell/em-hist.el
@@ -399,7 +399,7 @@ input."
                ('nil t)                 ; Always add to history
                ('erase                  ; Add, removing any old occurrences
                 (when-let ((old-index (ring-member eshell-history-ring input)))
-                  ;; Remove the old occurence of this input so we can
+                  ;; Remove the old occurrence of this input so we can
                   ;; add it to the end.  FIXME: Should we try to
                   ;; remove multiple old occurrences, e.g. if the user
                   ;; recently changed to using `erase'?
diff --git a/lisp/jsonrpc.el b/lisp/jsonrpc.el
index 849a8d8eaee..7726712d056 100644
--- a/lisp/jsonrpc.el
+++ b/lisp/jsonrpc.el
@@ -158,7 +158,7 @@ immediately."
 (defvar jsonrpc-inhibit-debug-on-error nil
   "Inhibit `debug-on-error' when answering requests.
 Some extensions, notably ert.el, set `debug-on-error' to non-nil,
-which makes it hard to test the behaviour of catching the Elisp
+which makes it hard to test the behavior of catching the Elisp
 error and replying to the endpoint with an JSONRPC-error.  This
 variable can be set around calls like `jsonrpc-request' to
 circumvent that.")
diff --git a/lisp/minibuffer.el b/lisp/minibuffer.el
index e5c5fd62f8c..a9814fb0bac 100644
--- a/lisp/minibuffer.el
+++ b/lisp/minibuffer.el
@@ -1685,7 +1685,7 @@ names, where this is the directory component of the file 
name.")
   "Sort COMPLETIONS by their position in `minibuffer-history-variable'.
 
 COMPLETIONS are sorted first by `minibuffer-sort-alphbetically',
-then any elements occuring in the minibuffer history list are
+then any elements occurring in the minibuffer history list are
 moved to the front based on the chronological order they occur in
 the history.  If a history variable hasn't been specified for
 this call of `completing-read', COMPLETIONS are sorted only by
@@ -4942,7 +4942,7 @@ This is run upon minibuffer setup."
 (defun minibuffer-exit-on-screen-keyboard ()
   "Hide the on-screen keyboard if it was displayed.
 Hide the on-screen keyboard in a timer set to run in 0.1 seconds.
-It will be cancelled if the minibuffer is displayed again within
+It will be canceled if the minibuffer is displayed again within
 that timeframe.
 
 Do not hide the on screen keyboard inside a recursive edit.
diff --git a/lisp/net/shr.el b/lisp/net/shr.el
index 9f030b4c743..e0888c61496 100644
--- a/lisp/net/shr.el
+++ b/lisp/net/shr.el
@@ -200,7 +200,7 @@ inline if it occupies less than this fraction of window 
width.
 
 HEIGHT can be also be an integer or a floating point number.  If it is an
 integer and the pixel height of an image exceeds it, the image image is
-displyed on a separate line.  If it is a float number , the limit is
+displayed on a separate line.  If it is a float number , the limit is
 interpreted as a multiple of the height of default font."
   :version "30.1"
   :type '(choice (const nil) (cons number number)))
diff --git a/lisp/net/tramp-crypt.el b/lisp/net/tramp-crypt.el
index 379b8b70656..0d79f88f10c 100644
--- a/lisp/net/tramp-crypt.el
+++ b/lisp/net/tramp-crypt.el
@@ -856,7 +856,7 @@ WILDCARD is not supported."
      'unlock-file (tramp-crypt-encrypt-file-name filename))))
 
 (defun tramp-crypt-cleanup-connection (vec)
-  "Cleanup crypt ressources determined by VEC."
+  "Cleanup crypt resources determined by VEC."
   (let ((tramp-cleanup-connection-hook
         (remove
          #'tramp-crypt-cleanup-connection tramp-cleanup-connection-hook)))
diff --git a/lisp/net/tramp-message.el b/lisp/net/tramp-message.el
index 8afc8d5fd87..e05357f1f4f 100644
--- a/lisp/net/tramp-message.el
+++ b/lisp/net/tramp-message.el
@@ -515,7 +515,7 @@ This shouldn't be changed globally, but let-bind where 
needed.")
 Bound in `tramp-*-file-name-handler' functions.")
 
 (defun tramp-debug-message-buttonize (position)
-  "Buttonize function in current buffer, at next line starting after POSTION."
+  "Buttonize function in current buffer, at next line starting after POSITION."
   (declare (tramp-suppress-trace t))
   (save-excursion
     (goto-char position)
diff --git a/lisp/progmodes/cc-engine.el b/lisp/progmodes/cc-engine.el
index 018a194ac14..6154253e6b3 100644
--- a/lisp/progmodes/cc-engine.el
+++ b/lisp/progmodes/cc-engine.el
@@ -7554,7 +7554,7 @@ multi-line strings (but not C++, for example)."
 (defun c-ml-string-opener-intersects-region (&optional start finish)
   ;; If any part of the region [START FINISH] is inside an ml-string opener,
   ;; return a dotted list of the start, end and double-quote position of the
-  ;; first such opener.  That list wlll not include any "context characters"
+  ;; first such opener.  That list will not include any "context characters"
   ;; before or after the opener.  If an opener is found, the match-data will
   ;; indicate it, with (match-string 1) being the entire delimiter, and
   ;; (match-string 2) the "main" double-quote.  Otherwise, the match-data is
@@ -9891,7 +9891,7 @@ point unchanged and return nil."
   ;; Note that this function is incomplete, handling only those cases expected
   ;; to be common in a C++20 requires clause.
   ;;
-  ;; Note also that (...) is not recognised as a primary expression if the
+  ;; Note also that (...) is not recognized as a primary expression if the
   ;; next token is an open brace.
   (let ((here (point))
        (c-restricted-<>-arglists t)
@@ -13021,7 +13021,7 @@ comment at the start of cc-engine.el for more info."
 
 (defun c-laomib-get-cache (containing-sexp start)
   ;; Get an element from `c-laomib-cache' matching CONTAINING-SEXP, and which
-  ;; is suitable for start postiion START.
+  ;; is suitable for start position START.
   ;; Return that element or nil if one wasn't found.
   (let ((ptr c-laomib-cache)
        elt)
diff --git a/lisp/progmodes/cperl-mode.el b/lisp/progmodes/cperl-mode.el
index 02185972bfe..58cf2728f61 100644
--- a/lisp/progmodes/cperl-mode.el
+++ b/lisp/progmodes/cperl-mode.el
@@ -4206,7 +4206,7 @@ recursive calls in starting lines of here-documents."
                    (setq tmpend tb))
                (put-text-property b (point) 'syntax-type 'format))
               ;; quotelike operator or regexp: capture groups 10 or 11
-               ;; matches some false postives, to be eliminated here
+               ;; matches some false positives, to be eliminated here
               ((or (match-beginning 10) (match-beginning 11))
                (setq b1 (if (match-beginning 10) 10 11)
                      argument (buffer-substring
@@ -5877,7 +5877,7 @@ functions (which they are not).  Inherits from 
`default'.")
                                              (eval cperl--ws*-rx))
                                    ;; ... or the start of a "sloppy" signature
                                    (sequence (eval cperl--sloppy-signature-rx)
-                                             ;; arbtrarily continue "a few 
lines"
+                                             ;; arbitrarily continue "a few 
lines"
                                              (repeat 0 200 (not (in "{"))))
                                    ;; make sure we have a reasonably
                                    ;; short match for an incomplete sub
diff --git a/lisp/progmodes/gud.el b/lisp/progmodes/gud.el
index eb35287cabe..0f0bb73ae77 100644
--- a/lisp/progmodes/gud.el
+++ b/lisp/progmodes/gud.el
@@ -3974,11 +3974,11 @@ def gud_complete(s, max):
         print(f'\"{string_list.GetStringAtIndex(i)}\" ')
     print(')##')
 "
-  "Python code sent to LLDB for gud-specific initialisation.")
+  "Python code sent to LLDB for gud-specific initialization.")
 
 (defun gud-lldb-fetch-completions (context command)
   "Return the data to complete the LLDB command before point.
-This is what the Python function we installed at initialzation
+This is what the Python function we installed at initialization
 time returns, as a Lisp list.
 Maximum number of completions requested from LLDB is controlled
 by `gud-lldb-max-completions', which see."
diff --git a/lisp/simple.el b/lisp/simple.el
index d60acf5477a..cee1ddac52f 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -11178,7 +11178,7 @@ For each insertion:
     enabled.
 
   - Look for the deletion of a single electric pair character,
-    and delete the adjascent pair if
+    and delete the adjacent pair if
     `electric-pair-delete-adjacent-pairs'.
 
   - Run `post-self-insert-hook' for the last character of
diff --git a/lisp/term/android-win.el b/lisp/term/android-win.el
index 36470097b40..3e759a37a71 100644
--- a/lisp/term/android-win.el
+++ b/lisp/term/android-win.el
@@ -340,7 +340,7 @@ the `stop-selecting-text' editing key."
 
 
 ;; Splash screen notice.  Users are frequently left scratching their
-;; heads when they overlook the Android appendex in the Emacs manual
+;; heads when they overlook the Android appendix in the Emacs manual
 ;; and discover that external storage is not accessible; worse yet,
 ;; Android 11 and later veil the settings panel controlling such
 ;; permissions behind layer upon layer of largely immaterial settings
diff --git a/lisp/touch-screen.el b/lisp/touch-screen.el
index bae0e097688..a10bdea8994 100644
--- a/lisp/touch-screen.el
+++ b/lisp/touch-screen.el
@@ -57,7 +57,7 @@ touch point being tracked, the window where the touch began, a
 cons holding the initial position of the touch point, and the
 last known position of the touch point, all in the same format as
 in `touch-screen-current-tool', the distance in pixels between
-the current tool and the aformentioned initial position, the
+the current tool and the aforementioned initial position, the
 center of the line formed between those two points, the ratio
 between the present distance between both tools and the aforesaid
 initial distance when a pinch gesture was last sent, and three
@@ -1927,7 +1927,7 @@ with that event and DATA.
 
 If THRESHOLD is non-nil, enforce a threshold of movement that is
 either itself or 10 pixels when it is not a number.  If the
-aformentioned touch point moves beyond that threshold on any
+aforementioned touch point moves beyond that threshold on any
 axis, return nil immediately, and further resume mouse event
 translation for the touch point at hand.
 
diff --git a/lisp/transient.el b/lisp/transient.el
index 94f7700ddaf..ebf6f23f6cd 100644
--- a/lisp/transient.el
+++ b/lisp/transient.el
@@ -1514,7 +1514,7 @@ invoked from.
 Regular suffix commands, which are not prefixes, do not have to
 concern themselves with this distinction, so they can use this
 function instead.  In the context of a plain suffix, it always
-returns the value of the appropiate variable."
+returns the value of the appropriate variable."
   (or transient--prefix transient-current-prefix))
 
 (defun transient-suffix-object (&optional command)
diff --git a/lisp/treesit.el b/lisp/treesit.el
index da8226f7d8a..9f885985f3b 100644
--- a/lisp/treesit.el
+++ b/lisp/treesit.el
@@ -690,7 +690,7 @@ property.  If LANGUAGE is non-nil, only return parsers for 
LANGUAGE."
 
 (defun treesit--update-ranges-local
     (query embedded-lang &optional beg end)
-  "Update range for local parsers betwwen BEG and END.
+  "Update range for local parsers between BEG and END.
 Use QUERY to get the ranges, and make sure each range has a local
 parser for EMBEDDED-LANG."
   ;; Clean up.
diff --git a/lisp/use-package/use-package-core.el 
b/lisp/use-package/use-package-core.el
index 34c45b7aec3..2897b60b2f9 100644
--- a/lisp/use-package/use-package-core.el
+++ b/lisp/use-package/use-package-core.el
@@ -1619,7 +1619,7 @@ ARG is the normalized input to the `:vc' keyword, as 
returned by
 the `use-package-normalize/:vc' function.
 
 REST is a plist of other (following) keywords and their
-arguments, each having already been normalised by the respective
+arguments, each having already been normalized by the respective
 function.
 
 STATE is a plist of any state that keywords processed before
@@ -1690,7 +1690,7 @@ node `(use-package) Creating an extension'."
       (`(,(pred symbolp) . ,(or (pred plistp)    ; plist/version string + name
                                 (pred stringp)))
        (use-package-normalize--vc-arg arg))
-      (_ (use-package-error "Unrecognised argument to :vc.\
+      (_ (use-package-error "Unrecognized argument to :vc.\
  The keyword wants an argument of nil, t, a name of a package,\
  or a cons-cell as accepted by `package-vc-selected-packages', where \
  the accepted plist is augmented by a `:rev' keyword.")))))
diff --git a/src/android.c b/src/android.c
index 51622f16230..7a393f8f56d 100644
--- a/src/android.c
+++ b/src/android.c
@@ -2779,7 +2779,7 @@ android_destroy_handle (android_handle handle)
 
   /* Just clear any exception thrown.  If destroying the handle
      fails from an out-of-memory error, then Emacs loses some
-     resources, but that is not as big deal as signalling.  */
+     resources, but that is not as big deal as signaling.  */
   (*android_java_env)->ExceptionClear (android_java_env);
 
   /* Delete the global reference regardless of any error.  */
@@ -5797,7 +5797,7 @@ android_check_string (Lisp_Object text)
    better represent the UCS-16 based Java String format, and to let
    strings contain NULL characters while remaining valid C strings:
    NULL bytes are encoded as two-byte sequences, and Unicode surrogate
-   pairs encoded as two-byte sequences are prefered to four-byte
+   pairs encoded as two-byte sequences are preferred to four-byte
    sequences when encoding characters above the BMP.  */
 
 int
diff --git a/src/androidselect.c b/src/androidselect.c
index f7988db0520..e7a6ee258a8 100644
--- a/src/androidselect.c
+++ b/src/androidselect.c
@@ -299,7 +299,7 @@ data type available from the clipboard.  */)
                                                bytes_array);
   for (i = 0; i < length; ++i)
     {
-      /* Retireve the MIME type.  */
+      /* Retrieve the MIME type.  */
       bytes
        = (*android_java_env)->GetObjectArrayElement (android_java_env,
                                                      bytes_array, i);
diff --git a/src/androidterm.c b/src/androidterm.c
index cfb64cd69a0..c3a04fd3cfb 100644
--- a/src/androidterm.c
+++ b/src/androidterm.c
@@ -6101,7 +6101,7 @@ android_update_selection (struct frame *f, struct window 
*w)
   else
     start = -1, end = -1;
 
-  /* Now constrain START and END to the maximium size of a Java
+  /* Now constrain START and END to the maximum size of a Java
      integer.  */
   start = min (start, TYPE_MAXIMUM (jint));
   end = min (end, TYPE_MAXIMUM (jint));
@@ -6238,7 +6238,7 @@ android_reset_conversion (struct frame *f)
 
   android_reset_ic (FRAME_ANDROID_WINDOW (f), mode);
 
-  /* Clear extracted text flags.  Since the IM has been reinitialised,
+  /* Clear extracted text flags.  Since the IM has been reinitialized,
      it should no longer be displaying extracted text.  */
   FRAME_ANDROID_OUTPUT (f)->extracted_text_flags = 0;
 
diff --git a/src/androidterm.h b/src/androidterm.h
index e75d46b1dfb..9830cc4364d 100644
--- a/src/androidterm.h
+++ b/src/androidterm.h
@@ -262,7 +262,7 @@ struct android_output
      text''.  */
   int extracted_text_flags;
 
-  /* Token asssociated with that request.  */
+  /* Token associated with that request.  */
   int extracted_text_token;
 
   /* The number of characters of extracted text wanted by the IM.  */
diff --git a/src/androidvfs.c b/src/androidvfs.c
index 51558d2a375..3b7fb731e86 100644
--- a/src/androidvfs.c
+++ b/src/androidvfs.c
@@ -407,7 +407,7 @@ android_init_fd_class (JNIEnv *env)
    values are prohibitively slow, but smaller values can't face up to
    some long file names within several nested layers of directories.
 
-   Buffers holding components or other similar file name constitutents
+   Buffers holding components or other similar file name constituents
    which don't represent SAF files must continue to use PATH_MAX, for
    that is the restriction imposed by the Unix file system.  */
 
@@ -4179,7 +4179,7 @@ android_saf_stat (const char *uri_name, const char 
*id_name,
 }
 
 /* Detect if Emacs has access to the document designated by the the
-   documen ID ID_NAME within the tree URI_NAME.  If ID_NAME is NULL,
+   document ID ID_NAME within the tree URI_NAME.  If ID_NAME is NULL,
    use the document ID in URI_NAME itself.
 
    If WRITABLE, also check that the file is writable, which is true
@@ -6427,7 +6427,7 @@ android_root_name (struct android_vnode *vnode, char 
*name,
   if (!component_end)
     component_end = name + length;
   else
-    /* Move past the spearator character.  */
+    /* Move past the separator character.  */
     component_end++;
 
   /* Now, find out if the first component is a special vnode; if so,
@@ -7172,7 +7172,7 @@ android_readlinkat (int dirfd, const char *restrict 
pathname,
    while file streams also require ownership over file descriptors
    they are created on behalf of.
 
-   Detaching the parcel file descriptor linked to FD consequentially
+   Detaching the parcel file descriptor linked to FD consequently
    prevents the owner from being notified when it is eventually
    closed, but for now that hasn't been demonstrated to be problematic
    yet, as Emacs doesn't write to file streams.  */
diff --git a/src/fileio.c b/src/fileio.c
index 51937e6d765..64f255a355b 100644
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -203,7 +203,7 @@ check_vfs_filename (Lisp_Object encoded, const char *reason)
 #ifdef HAVE_LIBSELINUX
 
 /* Return whether SELinux is enabled and pertinent to FILE.  Provide
-   for cases where FILE is or is a constitutent of a special
+   for cases where FILE is or is a constituent of a special
    directory, such as /assets or /content on Android.  */
 
 static bool
diff --git a/src/image.c b/src/image.c
index 29ec6d5381b..38744fc1cce 100644
--- a/src/image.c
+++ b/src/image.c
@@ -11785,7 +11785,7 @@ svg_css_length_to_pixels (RsvgLength length, double 
dpi, int font_size)
 
         If we do set explicit width and height values in the image
         spec, this will work out correctly as librsvg will still
-        honour the percentage sizes in its final rendering no matter
+        honor the percentage sizes in its final rendering no matter
         what size we make the image.  */
       value = 0;
       break;
diff --git a/src/process.c b/src/process.c
index bde87b78701..8bc922ab509 100644
--- a/src/process.c
+++ b/src/process.c
@@ -7520,7 +7520,7 @@ handle_child_signal (int sig)
 
                   emacs_unlink is not async signal safe because
                   deleting files from content providers must proceed
-                  through Java code.  Consequentially, if XCDR (head)
+                  through Java code.  Consequently, if XCDR (head)
                   lies on a content provider it will not be removed,
                   which is a bug.  */
                unlink (SSDATA (XCDR (head)));
diff --git a/src/regex-emacs.c b/src/regex-emacs.c
index cb4fbd58faa..19bec537130 100644
--- a/src/regex-emacs.c
+++ b/src/regex-emacs.c
@@ -2824,7 +2824,7 @@ group_in_compile_stack (compile_stack_type compile_stack, 
regnum_t regnum)
 
 /* Iterate through all the char-matching operations directly reachable from P.
    This is the inner loop of `forall_firstchar`, which see.
-   LOOP_BEG..LOOP_END delimit the currentl "block" of code (we assume
+   LOOP_BEG..LOOP_END delimit the currently "block" of code (we assume
    the code is made of syntactically nested loops).
    LOOP_END is blindly assumed to be "safe".
    To guarantee termination, at each iteration, either LOOP_BEG should
diff --git a/src/sfnt.c b/src/sfnt.c
index bc2ffdea9dc..238e7f48420 100644
--- a/src/sfnt.c
+++ b/src/sfnt.c
@@ -4762,7 +4762,7 @@ sfnt_get_scale (struct sfnt_head_table *head, int ppem)
   /* Figure out how to convert from font unit-space to pixel space.
      To turn one unit to its corresponding pixel size given a ppem of
      1, the unit must be divided by head->units_per_em.  Then, it must
-     be multipled by the ppem.  So,
+     be multiplied by the ppem.  So,
 
        PIXEL = UNIT / UPEM * PPEM
 
@@ -4902,7 +4902,7 @@ sfnt_read_name_table (int fd, struct sfnt_offset_subtable 
*subtable)
       return NULL;
     }
 
-  /* Read REQURIED bytes into the string data.  */
+  /* Read REQUIRED bytes into the string data.  */
   name->data = (unsigned char *) (name->name_records
                                  + name->count);
   rc = read (fd, name->data, required);
@@ -14256,7 +14256,7 @@ sfnt_infer_deltas_1 (struct sfnt_glyph *glyph, size_t 
start,
            }
          else
            {
-             /* ... otheriwse, move point j by the delta of the
+             /* ... otherwise, move point j by the delta of the
                 nearest touched point.  */
 
              if (x[j] >= max_pos)
@@ -14320,7 +14320,7 @@ sfnt_infer_deltas_1 (struct sfnt_glyph *glyph, size_t 
start,
            }
          else
            {
-             /* ... otheriwse, move point j by the delta of the
+             /* ... otherwise, move point j by the delta of the
                 nearest touched point.  */
 
              if (y[j] >= max_pos)
@@ -14404,7 +14404,7 @@ sfnt_infer_deltas_1 (struct sfnt_glyph *glyph, size_t 
start,
            }
          else
            {
-             /* ... otheriwse, move point j by the delta of the
+             /* ... otherwise, move point j by the delta of the
                 nearest touched point.  */
 
              if (x[j] >= max_pos)
@@ -14468,7 +14468,7 @@ sfnt_infer_deltas_1 (struct sfnt_glyph *glyph, size_t 
start,
            }
          else
            {
-             /* ... otheriwse, move point j by the delta of the
+             /* ... otherwise, move point j by the delta of the
                 nearest touched point.  */
 
              if (y[j] >= max_pos)
@@ -14557,7 +14557,7 @@ sfnt_infer_deltas (struct sfnt_glyph *glyph, bool 
*touched,
    of one or two coordinates for each axis.  Each such list is
    referred to as a ``tuple''.
 
-   The deltas, one for each point, are multipled by the normalized
+   The deltas, one for each point, are multiplied by the normalized
    value of each axis and applied to those points for each tuple that
    is found to be applicable.
 
diff --git a/src/sfnt.h b/src/sfnt.h
index f6ab6a6eebd..42ae64c362b 100644
--- a/src/sfnt.h
+++ b/src/sfnt.h
@@ -1283,7 +1283,7 @@ struct sfnt_gvar_table
   unsigned char *glyph_variation_data;
 };
 
-/* Structure repesenting a set of axis coordinates and their
+/* Structure representing a set of axis coordinates and their
    normalized equivalents.
 
    To use this structure, call
diff --git a/src/sfntfont.c b/src/sfntfont.c
index 68e850779fc..f002712dc10 100644
--- a/src/sfntfont.c
+++ b/src/sfntfont.c
@@ -1348,7 +1348,7 @@ sfntfont_charset_for_cmap (struct 
sfnt_cmap_encoding_subtable subtable)
    subtable in *SUBTABLE upon success, NULL otherwise.
 
    If FORMAT14 is non-NULL, return any associated format 14 variation
-   selection context in *FORMAT14 should the selected charcter map be
+   selection context in *FORMAT14 should the selected character map be
    a Unicode character map.  */
 
 static struct sfnt_cmap_encoding_subtable_data *
@@ -1371,7 +1371,7 @@ sfntfont_select_cmap (struct sfnt_cmap_table *cmap,
          if (!format14)
            return data[i];
 
-         /* Search for a correspoinding format 14 character map.
+         /* Search for a corresponding format 14 character map.
             This is used in conjunction with the selected character
             map to map variation sequences.  */
 
@@ -1400,7 +1400,7 @@ sfntfont_select_cmap (struct sfnt_cmap_table *cmap,
          if (!format14)
            return data[i];
 
-         /* Search for a correspoinding format 14 character map.
+         /* Search for a corresponding format 14 character map.
             This is used in conjunction with the selected character
             map to map variation sequences.  */
 
diff --git a/src/treesit.c b/src/treesit.c
index 69b59fca111..912f4ed47cc 100644
--- a/src/treesit.c
+++ b/src/treesit.c
@@ -3335,7 +3335,7 @@ treesit_traverse_validate_predicate (Lisp_Object pred,
          if (!CONSP (cdr))
            {
              *signal_data = list3 (Qtreesit_invalid_predicate,
-                                   build_string ("Invalide `not' "
+                                   build_string ("Invalid `not' "
                                                  "predicate"),
                                    pred);
              return false;
diff --git a/src/window.h b/src/window.h
index 9ef8434af18..346dc70ea98 100644
--- a/src/window.h
+++ b/src/window.h
@@ -292,7 +292,7 @@ struct window
 
        `last_point' is normally used during redisplay to indicate the
        position of point as seem by the input method.  However, it is
-       not updated if consequtive conversions are processed at the
+       not updated if consecutive conversions are processed at the
        same time.
 
        This `ephemeral_last_point' field is either the last point as
diff --git a/src/xselect.c b/src/xselect.c
index c38a1f8b6a9..5ffa0fd24fc 100644
--- a/src/xselect.c
+++ b/src/xselect.c
@@ -897,7 +897,7 @@ x_start_selection_transfer (struct x_display_info *dpyinfo, 
Window requestor,
 
       /* Find a valid (non-zero) serial for the selection transfer.
         Any asynchronously trapped errors will then cause the
-        selection transfer to be cancelled.  */
+        selection transfer to be canceled.  */
       transfer->serial = (++selection_serial
                          ? selection_serial
                          : ++selection_serial);
diff --git a/src/xterm.c b/src/xterm.c
index 75ac8d0d555..79648a6d6e5 100644
--- a/src/xterm.c
+++ b/src/xterm.c
@@ -616,9 +616,9 @@ along with GNU Emacs.  If not, see 
<https://www.gnu.org/licenses/>.  */
     - x_clear_errors
 
   Callers using this set should consult the comment(s) on top of the
-  aformentioned functions.  They should not be used when the requests
+  aforementioned functions.  They should not be used when the requests
   being made do not require roundtrips to the X server, and obtaining
-  the details of any error generated is unecessary, as
+  the details of any error generated is unnecessary, as
   `x_uncatch_errors' will always synchronize with the X server, which
   is a potentially slow operation.  */
 
@@ -5173,7 +5173,7 @@ record_event (char *locus, int type)
 
 
 
-/* Miscelaneous event handling functions.  */
+/* Miscellaneous event handling functions.  */
 
 static void
 x_toolkit_position (struct frame *f, int x, int y,
@@ -11296,7 +11296,7 @@ x_clear_frame (struct frame *f)
 
 /* Send a message to frame F telling the event loop to track whether
    or not an hourglass is being displayed.  This is required to ignore
-   the right events when the hourglass is mapped without callig XSync
+   the right events when the hourglass is mapped without calling XSync
    after displaying or hiding the hourglass.  */
 
 static void
@@ -32094,7 +32094,7 @@ x_initialize (void)
 
 #ifdef HAVE_X_I18N
 
-/* Notice that a change has occured on F that requires its input
+/* Notice that a change has occurred on F that requires its input
    method state to be reset.  */
 
 static void
diff --git a/test/lisp/emacs-lisp/bytecomp-tests.el 
b/test/lisp/emacs-lisp/bytecomp-tests.el
index 27056c99a50..8fbe48bbb9a 100644
--- a/test/lisp/emacs-lisp/bytecomp-tests.el
+++ b/test/lisp/emacs-lisp/bytecomp-tests.el
@@ -717,7 +717,7 @@ inner loops respectively."
       (set (make-local-variable 'bytecomp-tests--xx) 2)
       bytecomp-tests--xx)
 
-    ;; Check for-effect optimisation of `condition-case' body form.
+    ;; Check for-effect optimization of `condition-case' body form.
     ;; With `condition-case' in for-effect context:
     (let ((x (bytecomp-test-identity ?A))
           (r nil))
@@ -797,7 +797,7 @@ inner loops respectively."
     (let ((x 0))
       (list (= (setq x 1))
             x))
-    ;; Aristotelian identity optimisation
+    ;; Aristotelian identity optimization
     (let ((x (bytecomp-test-identity 1)))
       (list (eq x x) (eql x x) (equal x x)))
     )
@@ -2120,7 +2120,7 @@ EXPECTED-POINT BINDINGS (MODES \\='\\='(ruby-mode js-mode 
python-mode)) \
     ))
 
 (ert-deftest bytecomp--byte-op-error-backtrace ()
-  "Check that signalling byte ops show up in the backtrace."
+  "Check that signaling byte ops show up in the backtrace."
   (dolist (case bytecomp-tests--byte-op-error-cases)
     (ert-info ((prin1-to-string case) :prefix "case: ")
       (let* ((call (nth 0 case))
@@ -2151,7 +2151,7 @@ EXPECTED-POINT BINDINGS (MODES \\='\\='(ruby-mode js-mode 
python-mode)) \
                                call))))))))))
 
 (ert-deftest bytecomp--eq-symbols-with-pos-enabled ()
-  ;; Verify that we don't optimise away a binding of
+  ;; Verify that we don't optimize away a binding of
   ;; `symbols-with-pos-enabled' around an application of `eq' (bug#65017).
   (let* ((sym-with-pos1 (read-positioning-symbols "sym"))
          (sym-with-pos2 (read-positioning-symbols " sym"))  ; <- space!
diff --git a/test/lisp/erc/erc-scenarios-base-attach.el 
b/test/lisp/erc/erc-scenarios-base-attach.el
index ccf5d1f9582..29f5bd2ddd8 100644
--- a/test/lisp/erc/erc-scenarios-base-attach.el
+++ b/test/lisp/erc/erc-scenarios-base-attach.el
@@ -47,11 +47,11 @@
 ;;   Author:     Mario Lang <mlang@delysid.org>
 ;;   AuthorDate: Mon Nov 26 18:33:19 2001 +0000
 ;;
-;;   * new function erc-BBDB-NICK to handle nickname anotation ...
+;;   * new function erc-BBDB-NICK to handle nickname annotation ...
 ;;   * Applied antifuchs/mhp patches, the latest on erc-help, unmodified
 ;;   * New variable: erc-reuse-buffers default to t.
 ;;   * Modified erc-generate-new-buffer-name to use it. it checks if
-;;     server and port are the same, then one can assume thats the same
+;;     server and port are the same, then one can assume that's the same
 ;;     channel/query target again.
 
 ;;; Code:
diff --git a/test/lisp/erc/erc-tests.el b/test/lisp/erc/erc-tests.el
index 912a85ad5e0..e9bca2a3ac3 100644
--- a/test/lisp/erc/erc-tests.el
+++ b/test/lisp/erc/erc-tests.el
@@ -657,7 +657,7 @@
   (setq erc--isupport-params (make-hash-table))
 
   ;; Uses fallback values when no PREFIX parameter yet received, thus
-  ;; ensuring caller can use slot accessors immediately intead of
+  ;; ensuring caller can use slot accessors immediately instead of
   ;; checking if null beforehand.
   (should-not erc--parsed-prefix)
   (should (equal (erc--parsed-prefix)
@@ -2918,7 +2918,7 @@
     (while (accept-process-output proc 10))
     (goto-char (point-min))
     (unless (equal (read (current-buffer)) expected)
-      (message "Exepcted: %S\nGot: %s" expected (buffer-string))
+      (message "Expected: %S\nGot: %s" expected (buffer-string))
       (ert-fail "Mismatch"))))
 
 ;; Worrying about which library a module comes from is mostly not
diff --git a/test/lisp/eshell/em-hist-tests.el 
b/test/lisp/eshell/em-hist-tests.el
index 466d19cc6f7..078bcb490e5 100644
--- a/test/lisp/eshell/em-hist-tests.el
+++ b/test/lisp/eshell/em-hist-tests.el
@@ -35,7 +35,7 @@
 (cl-defun em-hist-test/check-history-file (file-name expected &optional
                                                      (expected-ring t))
   "Check that the contents of FILE-NAME match the EXPECTED history entries.
-Additonally, check that after loading the file, the history ring
+Additionally, check that after loading the file, the history ring
 matches too.  If EXPECTED-RING is a list, compare the ring
 elements against that; if t (the default), check against EXPECTED."
   (when (eq expected-ring t) (setq expected-ring expected))
diff --git a/test/lisp/eshell/esh-io-tests.el b/test/lisp/eshell/esh-io-tests.el
index 0201b6ab650..bc3d9c6e5d5 100644
--- a/test/lisp/eshell/esh-io-tests.el
+++ b/test/lisp/eshell/esh-io-tests.el
@@ -328,7 +328,7 @@ stdout originally pointed (the terminal)."
                                "tuodts\nrredts\n"))
 
 (ert-deftest esh-io-test/pipeline/subcommands ()
-  "Chek that all commands in a subcommand are properly piped."
+  "Check that all commands in a subcommand are properly piped."
   (skip-unless (executable-find "rev"))
   (with-temp-eshell
    (eshell-match-command-output "{echo foo; echo bar} | rev"
diff --git a/test/lisp/proced-tests.el b/test/lisp/proced-tests.el
index 44596f92490..58d97f46c4f 100644
--- a/test/lisp/proced-tests.el
+++ b/test/lisp/proced-tests.el
@@ -46,7 +46,7 @@
   (move-to-column (string-match attribute proced-header-line)))
 
 (defun proced--assert-process-valid-pid-refinement (pid)
-  "Fail unless the process at point could be present after a refinment using 
PID."
+  "Fail unless the process at point could be present after a refinement using 
PID."
   (proced--move-to-column "PID")
   (let ((pid-equal (string= pid (word-at-point))))
     (should
diff --git a/test/lisp/thingatpt-tests.el b/test/lisp/thingatpt-tests.el
index 7cf41d2817b..98ebf771717 100644
--- a/test/lisp/thingatpt-tests.el
+++ b/test/lisp/thingatpt-tests.el
@@ -85,16 +85,16 @@
     ("<foo@example.com>" 5 email "<foo@example.com>")
     ("<foo@example.com>" 16 email "<foo@example.com>")
     ("<foo@example.com>" 17 email "<foo@example.com>")
-    ;; email adresses containing numbers
+    ;; email addresses containing numbers
     ("foo1@example.com" 1 email "foo1@example.com")
     ("1foo@example.com" 1 email "1foo@example.com")
     ("11@example.com" 1 email "11@example.com")
     ("1@example.com" 1 email "1@example.com")
-    ;; email adresses user portion containing dots
+    ;; email addresses user portion containing dots
     ("foo.bar@example.com" 1 email "foo.bar@example.com")
     (".foobar@example.com" 1 email nil)
     (".foobar@example.com" 2 email "foobar@example.com")
-    ;; email adresses domain portion containing dots and dashes
+    ;; email addresses domain portion containing dots and dashes
     ("foobar@.example.com" 1 email nil)
     ("foobar@-example.com" 1 email "foobar@-example.com")
     ;; These are illegal, but thingatpt doesn't yet handle them
diff --git a/test/src/regex-emacs-tests.el b/test/src/regex-emacs-tests.el
index 615d905e140..2912ce8a571 100644
--- a/test/src/regex-emacs-tests.el
+++ b/test/src/regex-emacs-tests.el
@@ -912,7 +912,7 @@ This evaluates the TESTS test cases from glibc."
     ))
 
 (ert-deftest regexp-tests-zero-width-assertion-repetition ()
-  ;; Check compatibility behaviour with repetition operators after
+  ;; Check compatibility behavior with repetition operators after
   ;; certain zero-width assertions (bug#64128).
 
   ;; This function is just to hide ugly regexps from relint so that it



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/emacs-lisp/byte-opt.el b/lisp/emacs-lisp/byte-opt.el
index 7a61a8fce7e..5a72011c609 100644
--- a/lisp/emacs-lisp/byte-opt.el
+++ b/lisp/emacs-lisp/byte-opt.el
@@ -440,7 +440,7 @@ There can be multiple entries for the same NAME if it has 
several aliases.")
 
       (`(unwind-protect ,protected-expr :fun-body ,unwind-fun)
        ;; FIXME: The return value of UNWIND-FUN is never used so we
        ;; could potentially optimise it for-effect, but we don't do
        ;; that right no.
        `(,fn ,(byte-optimize-form protected-expr for-effect)
              :fun-body ,(byte-optimize-form unwind-fun)))
@@ -973,7 +973,7 @@ There can be multiple entries for the same NAME if it has 
several aliases.")
     (list (car form) (nth 2 form) (nth 1 form)))))
 
 (defun byte-opt--nary-comparison (form)
-  "Optimise n-ary comparisons such as `=', `<' etc."
+  "Optimize n-ary comparisons such as `=', `<' etc."
   (let ((nargs (length (cdr form))))
     (cond
      ((= nargs 1)
@@ -988,7 +988,7 @@ There can be multiple entries for the same NAME if it has 
several aliases.")
         (if (memq nil (mapcar #'macroexp-copyable-p (cddr form)))
             ;; At least one arg beyond the first is non-constant non-variable:
             ;; create temporaries for all args to guard against side-effects.
-            ;; The optimiser will eliminate trivial bindings later.
+            ;; The optimizer will eliminate trivial bindings later.
             (let ((i 1))
               (dolist (arg (cdr form))
                 (let ((var (make-symbol (format "arg%d" i))))
@@ -440,7 +440,7 @@ There can be multiple entries for the same NAME if it has 
       (`(unwind-protect ,protected-expr :fun-body ,unwind-fun)
        ;; FIXME: The return value of UNWIND-FUN is never used so we
-       ;; could potentially optimise it for-effect, but we don't do
+       ;; could potentially optimize it for-effect, but we don't do
        ;; that right no.
        `(,fn ,(byte-optimize-form protected-expr for-effect)
diff --git a/src/textconv.c b/src/textconv.c
index bd72562317f..fb1c66bb2c2 100644
--- a/src/textconv.c
+++ b/src/textconv.c
@@ -23,7 +23,7 @@ along with GNU Emacs.  If not, see 
<https://www.gnu.org/licenses/>.  */
    They may then request that the text editor remove or substitute
    that text for something else, for example when providing the
    ability to ``undo'' or ``edit'' previously composed text.  This is
-   most commonly seen in input methods for CJK laguages for X Windows,
+   most commonly seen in input methods for CJK languages for X Windows,
    and is extensively used throughout Android by input methods for all
    kinds of scripts.
 
@@ -1311,7 +1311,7 @@ struct complete_edit_check_context
 
 /* Convert PTR to CONTEXT.  If CONTEXT->check is false, then update
    CONTEXT->w's ephemeral last point and give it to the input method,
-   the assumption being that an editing operation signalled.  */
+   the assumption being that an editing operation signaled.  */
 
 static void
 complete_edit_check (void *ptr)
@@ -1379,7 +1379,7 @@ handle_pending_conversion_events_1 (struct frame *f,
      or not the editing operation completed successfully.  */
   context.check = false;
 
   /* Make sure completion is signalled.  */
   count = SPECPDL_INDEX ();
   record_unwind_protect_ptr (complete_edit, &token);
   w = NULL;
@@ -1379,7 +1379,7 @@ handle_pending_conversion_events_1 (struct frame *f,
   context.check = false;
 
-  /* Make sure completion is signalled.  */
+  /* Make sure completion is signaled.  */
   count = SPECPDL_INDEX ();
   record_unwind_protect_ptr (complete_edit, &token);